@@ -65,7 +65,7 @@ class Board:
 
         try:
             return os.environ["BLINKA_FORCEBOARD"]
-        except KeyError:  # no forced board, continue with testing!
+        except (AttributeError, KeyError):  # no forced board, continue with testing!
             pass
 
         chip_id = self.detector.chip.id
@@ -93,6 +93,8 @@ class Board:
             board_id = boards.FEATHER_M0_EXPRESS
         elif chip_id == chips.STM32F405:
             board_id = boards.PYBOARD
+        elif chip_id == chips.RP2040:
+            board_id = boards.RASPBERRY_PI_PICO
         elif chip_id == chips.S805:
             board_id = boards.ODROID_C1
         elif chip_id == chips.S905:
@@ -113,6 +115,10 @@ class Board:
             board_id = self._tegra_id()
         elif chip_id == chips.HFU540:
             board_id = self._sifive_id()
+        elif chip_id == chips.C906:
+            board_id = self._allwinner_id()
+        elif chip_id == chips.VICU7:
+            board_id = self.__beaglebone_id()
         elif chip_id == chips.MCP2221:
             board_id = boards.MICROCHIP_MCP2221
         elif chip_id == chips.BINHO:
@@ -238,6 +244,11 @@ class Board:
                 if id_string == bb_id[1]:
                     return model
 
+        board_value = self.detector.get_armbian_release_field("BOARD")
+
+        if board_value == "freedom-u74-arty":
+            return boards.BEAGLEV_STARFIV
+
         return None
 
     # pylint: enable=no-self-use
@@ -281,6 +292,8 @@ class Board:
             board = boards.ORANGE_PI_ZERO_PLUS_2H5
         elif board_value == "orangepizeroplus":
             board = boards.ORANGE_PI_ZERO_PLUS
+        elif board_value == "orangepizero2":
+            board = boards.ORANGE_PI_ZERO_2
         elif board_value == "nanopiair":
             board = boards.NANOPI_NEO_AIR
         elif board_value == "nanopiduo2":
@@ -342,6 +355,13 @@ class Board:
             return boards.SIFIVE_UNLEASHED
         return None
 
+    def _allwinner_id(self):
+        """Try to detect the id for Allwiner D1 board."""
+        board_value = self.detector.get_device_model()
+        if "sun20iw1p1" in board_value:
+            return boards.ALLWINER_D1
+        return None
+
     def _pine64_id(self):
         """Try to detect the id for Pine64 board or device."""
         board_value = self.detector.get_device_model()
