@@ -23,6 +23,8 @@ GENERIC_X86 = "GENERIC_X86"
 FT232H = "FT232H"
 FT2232H = "FT2232H"
 HFU540 = "HFU540"
+C906 = "C906"
+VICU7 = "VICU7"
 MCP2221 = "MCP2221"
 BINHO = "BINHO"
 MIPS24KC = "MIPS24KC"
@@ -39,6 +41,7 @@ LPC4330 = "LPC4330"
 RK3288 = "RK3288"
 PENTIUM_N3710 = "PENTIUM_N3710"  # SOC Braswell core
 STM32F405 = "STM32F405"
+RP2040 = "RP2040"
 STM32MP157 = "STM32MP157"
 MT8167 = "MT8167"
 ATOM_X5_Z8350 = "X5-Z8350"
